==> langpack-0.2.0.tgz: package/src/lp.ts <==
/// <reference path="./res.ts" />

namespace LangPack {

let en: LanguagePackInfoContract = {
    language: "en",
    strings: {
        prefix: "Prefix",
        suffix: "Suffix",
        month1: "Janunary",
        month2: "Febrary",
        month3: "March",
        month4: "April",
        month5: "May",
        month6: "June",
        month7: "July",
        month8: "August",
        month9: "September",
        month10: "October",
        month11: "November",
        month12: "December",
        month1s: "Jan",
        month2s: "Feb",
        month3s: "Mar",
        month4s: "Apr",
        month5s: "May",
        month6s: "Jun",
        month7s: "Jul",
        month8s: "Aug",
        month9s: "Sep",
        month10s: "Oct",
        month11s: "Nov",
        month12s: "Dec",
        weekDay0: "Sunday",
        weekDay1: "Monday",
        weekDay2: "Tuesday",
        weekDay3: "Wednesday",
        weekDay4: "Thursday",
        weekDay5: "Friday",
        weekDay6: "Saturday",
        weekDay0s: "Sun",
        weekDay1s: "Mon",
        weekDay2s: "Tue",
        weekDay3s: "Wed",
        weekDay4s: "Thu",
        weekDay5s: "Fri",
        weekDay6s: "Sat",
        weekDay0c: "S",
        weekDay1c: "M",
        weekDay2c: "T",
        weekDay3c: "W",
        weekDay4c: "T",
        weekDay5c: "F",
        weekDay6c: "S",
        am: "AM",
        pm: "PM",
        fewSecondsAgo: "Just now",
        secondsAgo: "{0}s ago",
        minutesAgo: "{0}min ago",
        hoursAgo: "{0}h ago",
        yesterday: "Yesterday",
        twoDaysAgo: "2d ago",
        daysAgo: "{0}d ago",
        fewSecondsLater: "Soon",
        secondsLater: "{0}s later",
        minutesLater: "{0}min later",
        hoursLater: "{0}h later",
        tomorrow: "Tomorrow",
        twoDaysLater: "2d later",
        daysLater: "{0}d later",
        today: "Today",
        timeDate: "{0} {1}",
        dateFull: "MM/DD/YYYY",
        dateFull2: "MMM D, YYYY",
        dateFull3: "www MMM D YYYY",
        dateShort: "MM/DD",
        dateShort2: "MMM D",
        dateYear: "YYYY",
        time12h: "{0} tt",
        minute: "{0} minutes",
        minute1: "minutes",
        minute2: "more then {0} minutes",
        oneDay: "1 day",
        oneWeek: "1 week",
        date: "Date",
        time: "Time",
        duration: "Duration",
        colon: ": ",
        comma: ", ",
        semicolon: "; ",
        periodMark: ". ",
        questionMark: "? ",
        exclamationSymbol: "! ",
        ldquo: "\"",
        rdquo: "\"",
        lsquo: "'",
        rsquo: "'",
        slightPauseMark: ", ",
        bookTitle: "{0}",
        name: "Name"
    },
    options: {
        lcid: 1033
    }
};

let zh_Hans: LanguagePackInfoContract = {
    language: ["zh", "zh-Hans", "zh-CHS", "zh-CN", "zh-SG", "zh-gan"],
    strings: {
        prefix: "前缀",
        suffix: "后缀",
        month1: "一月",
        month2: "二月",
        month3: "三月",
        month4: "四月",
        month5: "五月",
        month6: "六月",
        month7: "七月",
        month8: "八月",
        month9: "九月",
        month10: "十月",
        month11: "十一月",
        month12: "十二月",
        month1s: "1月",
        month2s: "2月",
        month3s: "3月",
        month4s: "4月",
        month5s: "5月",
        month6s: "6月",
        month7s: "7月",
        month8s: "8月",
        month9s: "9月",
        month10s: "10月",
        month11s: "11月",
        month12s: "12月",
        weekDay0: "星期日",
        weekDay1: "星期一",
        weekDay2: "星期二",
        weekDay3: "星期三",
        weekDay4: "星期四",
        weekDay5: "星期五",
        weekDay6: "星期六",
        weekDay0s: "周日",
        weekDay1s: "周一",
        weekDay2s: "周二",
        weekDay3s: "周三",
        weekDay4s: "周四",
        weekDay5s: "周五",
        weekDay6s: "周六",
        weekDay0c: "日",
        weekDay1c: "一",
        weekDay2c: "二",
        weekDay3c: "三",
        weekDay4c: "四",
        weekDay5c: "五",
        weekDay6c: "六",
        am: "上午",
        pm: "下午",
        fewSecondsAgo: "刚刚",
        secondsAgo: "{0}秒前",
        minutesAgo: "{0}分钟前",
        hoursAgo: "{0}小时前",
        yesterday: "昨天",
        twoDaysAgo: "前天",
        daysAgo: "{0}天前",
        fewSecondsLater: "即将",
        secondsLater: "{0}秒后",
        minutesLater: "{0}分钟后",
        hoursLater: "{0}小时后",
        tomorrow: "明天",
        twoDaysLater: "后天",
        daysLater: "{0}天后",
        today: "今天",
        timeDate: "{1} {0}",
        dateFull: "YYYY-MM-DD",
        dateFull2: "YYYY年M月D日",
        dateFull3: "YYYY年M月D日www",
        dateShort: "MM-DD",
        dateShort2: "M月D日",
        dateYear: "YYYY年",
        time12h: "tt{0}",
        minute: "{0}分钟",
        minute1: "分钟",
        minute2: " {0}分钟以上",
        oneDay: "一天",
        oneWeek: "一周",
        date: "日期",
        time: "时间",
        duration: "时长",
        colon: "：",
        comma: "，",
        semicolon: "；",
        periodMark: "。",
        questionMark: "？",
        exclamationSymbol: "！",
        ldquo: "“",
        rdquo: "”",
        lsquo: "“",
        rsquo: "”",
        slightPauseMark: "、",
        bookTitle: "《{0}》",
        name: "名称"
    },
    options: {
        lcid: 2052
    }
};

export const InnerResource = new Resources();
InnerResource.register(en);
InnerResource.register(zh_Hans);

}

==> langpack-1.0.1.tgz: package/src/lp.ts <==
/// <reference path="./res.ts" />

namespace LangPack {

let en: LanguagePackInfoContract = {
    language: "en",
    strings: {
        prefix: "Prefix",
        suffix: "Suffix",
        month1: "Janunary",
        month2: "Febrary",
        month3: "March",
        month4: "April",
        month5: "May",
        month6: "June",
        month7: "July",
        month8: "August",
        month9: "September",
        month10: "October",
        month11: "November",
        month12: "December",
        month1s: "Jan",
        month2s: "Feb",
        month3s: "Mar",
        month4s: "Apr",
        month5s: "May",
        month6s: "Jun",
        month7s: "Jul",
        month8s: "Aug",
        month9s: "Sep",
        month10s: "Oct",
        month11s: "Nov",
        month12s: "Dec",
        weekDay0: "Sunday",
        weekDay1: "Monday",
        weekDay2: "Tuesday",
        weekDay3: "Wednesday",
        weekDay4: "Thursday",
        weekDay5: "Friday",
        weekDay6: "Saturday",
        weekDay0s: "Sun",
        weekDay1s: "Mon",
        weekDay2s: "Tue",
        weekDay3s: "Wed",
        weekDay4s: "Thu",
        weekDay5s: "Fri",
        weekDay6s: "Sat",
        weekDay0c: "S",
        weekDay1c: "M",
        weekDay2c: "T",
        weekDay3c: "W",
        weekDay4c: "T",
        weekDay5c: "F",
        weekDay6c: "S",
        am: "AM",
        pm: "PM",
        fewSecondsAgo: "Just now",
        secondsAgo: "{0}s ago",
        minutesAgo: "{0}min ago",
        hoursAgo: "{0}h ago",
        yesterday: "Yesterday",
        twoDaysAgo: "2d ago",
        daysAgo: "{0}d ago",
        fewSecondsLater: "Soon",
        secondsLater: "{0}s later",
        minutesLater: "{0}min later",
        hoursLater: "{0}h later",
        tomorrow: "Tomorrow",
        twoDaysLater: "2d later",
        daysLater: "{0}d later",
        now: "Now",
        today: "Today",
        timeDate: "{0} {1}",
        dateFull: "MM/DD/YYYY",
        dateFull2: "MMM D, YYYY",
        dateFull3: "www MMM D YYYY",
        dateShort: "MM/DD",
        dateShort2: "MMM D",
        dateYear: "YYYY",
        time12h: "{0} tt",
        minute: "{0} minutes",
        minute1: "minutes",
        minute2: "more then {0} minutes",
        oneDay: "1 day",
        oneWeek: "1 week",
        date: "Date",
        time: "Time",
        duration: "Duration",
        colon: ": ",
        comma: ", ",
        semicolon: "; ",
        periodMark: ". ",
        questionMark: "? ",
        exclamationSymbol: "! ",
        ldquo: "\"",
        rdquo: "\"",
        lsquo: "'",
        rsquo: "'",
        slightPauseMark: ", ",
        bookTitle: "{0}",
        name: "Name",
        currentLanguage: "English"
    },
    options: {
        lcid: 1033
    }
};

let zh_Hans: LanguagePackInfoContract = {
    language: ["zh", "zh-Hans", "zh-CHS", "zh-CN", "zh-SG", "zh-cmn", "zh-gan", "zh-wu"],
    strings: {
        prefix: "前缀",
        suffix: "后缀",
        month1: "一月",
        month2: "二月",
        month3: "三月",
        month4: "四月",
        month5: "五月",
        month6: "六月",
        month7: "七月",
        month8: "八月",
        month9: "九月",
        month10: "十月",
        month11: "十一月",
        month12: "十二月",
        month1s: "1月",
        month2s: "2月",
        month3s: "3月",
        month4s: "4月",
        month5s: "5月",
        month6s: "6月",
        month7s: "7月",
        month8s: "8月",
        month9s: "9月",
        month10s: "10月",
        month11s: "11月",
        month12s: "12月",
        weekDay0: "星期日",
        weekDay1: "星期一",
        weekDay2: "星期二",
        weekDay3: "星期三",
        weekDay4: "星期四",
        weekDay5: "星期五",
        weekDay6: "星期六",
        weekDay0s: "周日",
        weekDay1s: "周一",
        weekDay2s: "周二",
        weekDay3s: "周三",
        weekDay4s: "周四",
        weekDay5s: "周五",
        weekDay6s: "周六",
        weekDay0c: "日",
        weekDay1c: "一",
        weekDay2c: "二",
        weekDay3c: "三",
        weekDay4c: "四",
        weekDay5c: "五",
        weekDay6c: "六",
        am: "上午",
        pm: "下午",
        fewSecondsAgo: "刚刚",
        secondsAgo: "{0}秒前",
        minutesAgo: "{0}分钟前",
        hoursAgo: "{0}小时前",
        yesterday: "昨天",
        twoDaysAgo: "前天",
        daysAgo: "{0}天前",
        fewSecondsLater: "即将",
        secondsLater: "{0}秒后",
        minutesLater: "{0}分钟后",
        hoursLater: "{0}小时后",
        tomorrow: "明天",
        twoDaysLater: "后天",
        daysLater: "{0}天后",
        now: "现在",
        today: "今天",
        timeDate: "{1} {0}",
        dateFull: "YYYY-MM-DD",
        dateFull2: "YYYY年M月D日",
        dateFull3: "YYYY年M月D日www",
        dateShort: "MM-DD",
        dateShort2: "M月D日",
        dateYear: "YYYY年",
        time12h: "tt{0}",
        minute: "{0}分钟",
        minute1: "分钟",
        minute2: " {0}分钟以上",
        oneDay: "一天",
        oneWeek: "一周",
        date: "日期",
        time: "时间",
        duration: "时长",
        colon: "：",
        comma: "，",
        semicolon: "；",
        periodMark: "。",
        questionMark: "？",
        exclamationSymbol: "！",
        ldquo: "“",
        rdquo: "”",
        lsquo: "‘",
        rsquo: "’",
        slightPauseMark: "、",
        bookTitle: "《{0}》",
        name: "名称",
        currentLanguage: "简体中文"
    },
    options: {
        lcid: 2052
    }
};

export const InnerResource = new Resources();
InnerResource.register(en);
InnerResource.register(zh_Hans);

}
